import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";

pane = Turbine.UI.Window();
pane:SetVisible(true);
pane:SetZOrder(2147483647);
pane.MouseEnter = function()
    pane:SetBackColor(Turbine.UI.Color(0.25, 1, 1, 1));
    if ((timeElapsed.prevTime == 0) or (timeElapsed.running)) then
        timerButton:SetVisible(true);
    end
end
pane.MouseLeave = function()
    pane:SetBackColor(nil);
    timerButton:Focus();
    timerButton:SetVisible(false);
end

serverCaption = Turbine.UI.Label();
serverCaption:SetParent(pane);
serverCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro16);
serverCaption:SetTextAlignment(Turbine.UI.ContentAlignment.BottomCenter);
serverCaption:SetForeColor(Turbine.UI.Color(1.0, 0.75, 0.0));
serverCaption:SetFontStyle(Turbine.UI.FontStyle.Outline);
serverCaption:SetOutlineColor(Turbine.UI.Color(0, 0, 0));
serverCaption:SetText("Server");
serverCaption:SetMouseVisible(false);

serverName = Turbine.UI.TextBox();
serverName:SetParent(pane);
serverName:SetFont(Turbine.UI.Lotro.Font.TrajanProBold22);
serverName:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter);
serverName:SetForeColor(Turbine.UI.Color(1.0, 1.0, 1.0));
serverName:SetFontStyle(Turbine.UI.FontStyle.Outline);
serverName:SetOutlineColor(Turbine.UI.Color(0, 0, 0));
serverName:SetMultiline(false);
serverName:SetText("(Enter Server Name)");
serverName:SetSelectable(true);

timeElapsedCaption = Turbine.UI.Label();
timeElapsedCaption:SetParent(pane);
timeElapsedCaption:SetFont(Turbine.UI.Lotro.Font.TrajanPro16);
timeElapsedCaption:SetTextAlignment(Turbine.UI.ContentAlignment.BottomCenter);
timeElapsedCaption:SetForeColor(Turbine.UI.Color(1.0, 0.75, 0.0));
timeElapsedCaption:SetFontStyle(Turbine.UI.FontStyle.Outline);
timeElapsedCaption:SetOutlineColor(Turbine.UI.Color(0, 0, 0));
timeElapsedCaption:SetText("Time Elapsed");
timeElapsedCaption:SetMouseVisible(false);

timeElapsed = Turbine.UI.Label();
timeElapsed:SetParent(pane);
timeElapsed:SetFont(Turbine.UI.Lotro.Font.TrajanProBold36);
timeElapsed:SetTextAlignment(Turbine.UI.ContentAlignment.TopCenter);
timeElapsed:SetForeColor(Turbine.UI.Color(1.0, 1.0, 1.0));
timeElapsed:SetFontStyle(Turbine.UI.FontStyle.Outline);
timeElapsed:SetOutlineColor(Turbine.UI.Color(0, 0, 0));
timeElapsed:SetText("00:00:00");
timeElapsed:SetMouseVisible(false);
timeElapsed.running = false;
timeElapsed.prevTime = 0;
timeElapsed.Update = function()
    local currentTime = math.floor(Turbine.Engine.GetGameTime());
    if (currentTime ~= timeElapsed.prevTime) then
        timeElapsed.prevTime = currentTime;
        local seconds = currentTime - timeElapsed.startTime;
        local hours = seconds / 3600;
        seconds = seconds % 3600;
        local minutes = seconds / 60;
        seconds = seconds % 60;
        timeElapsed:SetText(string.format("%2.2d:%2.2d:%2.2d", hours, minutes, seconds));
    end
end

timerButton = Turbine.UI.Lotro.Button();
timerButton:SetParent(pane);
timerButton:SetVisible(false);
timerButton:SetFont(Turbine.UI.Lotro.Font.TrajanPro13);
timerButton:SetText("Start");
timerButton.Click = function()
    if (timeElapsed.running) then
        timeElapsed.running = false;
        timeElapsed:SetWantsUpdates(false);
        timerButton:SetVisible(false);
        timeElapsedCaption:SetText("Final Time");
    else
        timeElapsed.startTime = math.floor(Turbine.Engine.GetGameTime())
        timeElapsed.running = true;
        timeElapsed:SetWantsUpdates(true);
        timerButton:SetText("Stop");
        serverName:SetMouseVisible(false);
    end
end

local width = 260;
local top = 0;

local h = 20;
serverCaption:SetSize(width, h);
serverCaption:SetPosition(0, top);
top = top + h;

h = 30;
serverName:SetSize(width, h);
serverName:SetPosition(0, top);
top = top + h;

h = 20;
timeElapsedCaption:SetSize(width, h);
timeElapsedCaption:SetPosition(0, top);
top = top + h;

h = 36;
timeElapsed:SetSize(width, h);
timeElapsed:SetPosition(0, top);
top = top + h;

w, h = 50, 20;
timerButton:SetSize(w, h);
timerButton:SetPosition(math.floor((width - w) / 2), top);
top = top + h;

local height = top + 5;
pane:SetSize(width, height);
pane:SetPosition(math.floor((Turbine.UI.Display.GetWidth() - width) / 2), 0);

pane.MouseDown = function()
    pane.prevMouseX, pane.prevMouseY = Turbine.UI.Display.GetMouseX(), Turbine.UI.Display.GetMouseY();
    pane.dragging = true;
end

pane.MouseUp = function()
    pane.dragging = false;
end

pane.MouseMove = function()
    if (pane.dragging) then
        local x, y = Turbine.UI.Display.GetMouseX(), Turbine.UI.Display.GetMouseY();
        deltaX, deltaY = x - pane.prevMouseX, y - pane.prevMouseY;
        pane:SetPosition(pane:GetLeft() + deltaX, pane:GetTop() + deltaY);
        pane.prevMouseX, pane.prevMouseY = x, y;
    end
end

Turbine.Shell.WriteLine("Event Timer v0.3, by Thurallor");
